[![Sourcery](https://img.shields.io/badge/Sourcery-refactored-blueviolet.svg)](https://sourcery.ai)
![](https://github.com/accent-starlette/starlette-core/workflows/Testing%20Workflow/badge.svg?branch=master)
![](https://github.com/accent-starlette/starlette-core/workflows/Deploy%20to%20GitHub%20Pages/badge.svg?branch=master)
![](https://codecov.io/gh/accent-starlette/starlette-core/branch/master/graph/badge.svg)

---

**Documentation**: [https://accent-starlette.github.io/starlette-core/](https://accent-starlette.github.io/starlette-core/)

---

# Starlette Core
